@@ -2,7 +2,7 @@ use crate::cards::five::Five;
 use crate::cards::two::Two;
 use crate::cards::{HandRanker, HandValidator, Permutator};
 use crate::hand_rank::HandRankValue;
-use crate::{CKCNumber, HandError, PokerCard};
+use crate::{CKCNumber, HandError, PokerCard, Shifty};
 use core::slice::Iter;
 use serde::{Deserialize, Serialize};
 
@@ -137,17 +137,20 @@ impl From<[CKCNumber; 7]> for Seven {
 }
 
 impl HandRanker for Seven {
-    fn hand_rank_value(&self) -> HandRankValue {
+    fn hand_rank_value_and_hand(&self) -> (HandRankValue, Five) {
         let mut best_hrv: HandRankValue = 0u16;
+        let mut best_hand = Five::default();
 
         for perm in Seven::FIVE_CARD_PERMUTATIONS {
-            let hrv = self.five_from_permutation(perm).hand_rank_value();
+            let hand = self.five_from_permutation(perm);
+            let hrv = hand.hand_rank_value();
             if (best_hrv == 0) || hrv != 0 && hrv < best_hrv {
                 best_hrv = hrv;
+                best_hand = hand;
             }
         }
 
-        best_hrv
+        (best_hrv, best_hand.sort())
     }
 
     fn hand_rank_value_validated(&self) -> HandRankValue {
@@ -203,6 +206,20 @@ impl Permutator for Seven {
     }
 }
 
+impl Shifty for Seven {
+    fn shift_suit(&self) -> Self {
+        Seven([
+            self.first().shift_suit(),
+            self.second().shift_suit(),
+            self.third().shift_suit(),
+            self.forth().shift_suit(),
+            self.fifth().shift_suit(),
+            self.sixth().shift_suit(),
+            self.seventh().shift_suit(),
+        ])
+    }
+}
+
 impl TryFrom<&'static str> for Seven {
     type Error = HandError;
 
@@ -295,6 +312,24 @@ mod cards_seven_tests {
         assert_eq!(7414, Seven::try_from("9S 8D 7C 5D 4♥ 3D 2D").unwrap().hand_rank_value());
     }
 
+    #[test]
+    fn hand_rank_value_and_hand() {
+        let (value, hand) = Seven::try_from("T♠ A♠ K♠ J♠ Q♠ 9♠ 8♠")
+            .unwrap()
+            .hand_rank_value_and_hand();
+
+        assert_eq!(hand, Five::try_from("A♠ K♠ Q♠ J♠ T♠").unwrap());
+        assert_eq!(value, 1);
+    }
+
+    #[test]
+    fn shifty__shift_suit() {
+        assert_eq!(
+            Seven::try_from("A♠ K♠ Q♠ J♠ T♠ 9♠ 8♠").unwrap().shift_suit(),
+            Seven::try_from("A♥ K♥ Q♥ J♥ T♥ 9♥ 8♥").unwrap()
+        )
+    }
+
     #[test]
     fn try_from__index() {
         let seven = Seven::try_from("A♠ K♠ Q♠ J♠ T♠ 9♠ 8♠");
