@@ -3,7 +3,7 @@ use crate::cards::three::Three;
 use crate::cards::two::Two;
 use crate::cards::{HandRanker, HandValidator, Permutator};
 use crate::hand_rank::HandRankValue;
-use crate::{CKCNumber, HandError, PokerCard};
+use crate::{CKCNumber, HandError, PokerCard, Shifty};
 use core::slice::Iter;
 use serde::{Deserialize, Serialize};
 
@@ -112,17 +112,20 @@ impl From<[CKCNumber; 6]> for Six {
 }
 
 impl HandRanker for Six {
-    fn hand_rank_value(&self) -> HandRankValue {
+    fn hand_rank_value_and_hand(&self) -> (HandRankValue, Five) {
         let mut best_hrv: HandRankValue = 0u16;
+        let mut best_hand = Five::default();
 
         for perm in Six::FIVE_CARD_PERMUTATIONS {
-            let hrv = self.five_from_permutation(perm).hand_rank_value();
+            let hand = self.five_from_permutation(perm);
+            let hrv = hand.hand_rank_value();
             if (best_hrv == 0) || hrv != 0 && hrv < best_hrv {
                 best_hrv = hrv;
+                best_hand = hand;
             }
         }
 
-        best_hrv
+        (best_hrv, best_hand.sort())
     }
 
     fn hand_rank_value_validated(&self) -> HandRankValue {
@@ -178,6 +181,19 @@ impl Permutator for Six {
     }
 }
 
+impl Shifty for Six {
+    fn shift_suit(&self) -> Self {
+        Six([
+            self.first().shift_suit(),
+            self.second().shift_suit(),
+            self.third().shift_suit(),
+            self.forth().shift_suit(),
+            self.fifth().shift_suit(),
+            self.sixth().shift_suit(),
+        ])
+    }
+}
+
 impl TryFrom<&'static str> for Six {
     type Error = HandError;
 
@@ -265,6 +281,14 @@ mod cards_six_tests {
         assert!(!six.is_valid());
     }
 
+    #[test]
+    fn shifty__shift_suit() {
+        assert_eq!(
+            Six::try_from("T♠ A♠ K♠ J♠ Q♠ 9♠").unwrap().shift_suit(),
+            Six::try_from("T♥ A♥ K♥ J♥ Q♥ 9♥").unwrap()
+        )
+    }
+
     #[test]
     fn try_from__index() {
         let six = Six::try_from("A♠ K♠ Q♠ J♠ T♠ 9♠");
